@@ -338,175 +338,6 @@ def fit_model_and_calc_local_idr(
     return local_idr
 
 
-def parse_args():
-    import argparse
-
-    parser = argparse.ArgumentParser(
-        formatter_class=argparse.RawTextHelpFormatter,
-        description="""
-Program: IDR (Irreproducible Discovery Rate)
-Version: {PACKAGE_VERSION}
-Contact: Nathan Boley <npboley@gmail.com>
-""".format(PACKAGE_VERSION=idrc.__version__))
-
-    def PossiblyGzippedFile(fname):
-        if fname.endswith(".gz"):
-            return io.TextIOWrapper(gzip.open(fname, 'rb'))
-        else:
-            return open(fname, 'r')
-    
-    parser.add_argument( '--samples', '-s', type=PossiblyGzippedFile, nargs=2, 
-                         required=True,
-                         help='Files containing peaks and scores.')
-    parser.add_argument( '--peak-list', '-p', type=PossiblyGzippedFile,
-        help='If provided, all peaks will be taken from this file.')
-    parser.add_argument( '--input-file-type', default='narrowPeak',
-                         choices=['narrowPeak', 'broadPeak', 'bed', 'gff'], 
-        help='File type of --samples and --peak-list.')
-    
-    parser.add_argument( '--rank',
-        help="Which column to use to rank peaks."\
-            +"\t\nOptions: signal.value p.value q.value columnIndex"\
-            +"\nDefaults:\n\tnarrowPeak/broadPeak: signal.value\n\tbed: score")
-    
-    default_ofname = "idrValues.txt"
-    parser.add_argument( '--output-file', "-o", 
-                         default=default_ofname, 
-        help='File to write output to.\nDefault: {}'.format(default_ofname))
-    parser.add_argument( '--output-file-type', 
-                         choices=['narrowPeak', 'broadPeak', 'bed'], 
-                         default=None, 
-        help='Output file type. Defaults to input file type when available, otherwise bed.')
-
-    parser.add_argument( '--log-output-file', "-l", type=argparse.FileType("w"),
-                         default=sys.stderr,
-                         help='File to write output to. Default: stderr')
-    
-    parser.add_argument( '--idr-threshold', "-i", type=float, default=None,
-        help="Only return peaks with a global idr threshold below this value."\
-            +"\nDefault: report all peaks")
-    parser.add_argument( '--soft-idr-threshold', type=float, default=None, 
-        help="Report statistics for peaks with a global idr below this "\
-        +"value but return all peaks with an idr below --idrc.\nDefault: %.2f" \
-                         % idrc.DEFAULT_SOFT_IDR_THRESH)
-
-    parser.add_argument( '--use-old-output-format', 
-                         action='store_true', default=False,
-                         help="Use old output format.")
-
-    parser.add_argument( '--plot', action='store_true', default=False,
-                         help='Plot the results to [OFNAME].png')
-        
-    parser.add_argument( '--use-nonoverlapping-peaks', 
-                         action="store_true", default=False,
-        help='Use peaks without an overlapping match and set the value to 0.')
-    
-    parser.add_argument( '--peak-merge-method', 
-                         choices=["sum", "avg", "min", "max"], default=None,
-        help="Which method to use for merging peaks.\n" \
-              + "\tDefault: 'sum' for signal/score/column indexes, 'min' for p/q-value.")
-
-    parser.add_argument( '--initial-mu', type=float, default=idrc.DEFAULT_MU,
-        help="Initial value of mu. Default: %.2f" % idrc.DEFAULT_MU)
-    parser.add_argument( '--initial-sigma', type=float, 
-                         default=idrc.DEFAULT_SIGMA,
-        help="Initial value of sigma. Default: %.2f" % idrc.DEFAULT_SIGMA)
-    parser.add_argument( '--initial-rho', type=float, default=idrc.DEFAULT_RHO,
-        help="Initial value of rho. Default: %.2f" % idrc.DEFAULT_RHO)
-    parser.add_argument( '--initial-mix-param', 
-        type=float, default=idrc.DEFAULT_MIX_PARAM,
-        help="Initial value of the mixture params. Default: %.2f" \
-                         % idrc.DEFAULT_MIX_PARAM)
-
-    parser.add_argument( '--fix-mu', action='store_true', 
-        help="Fix mu to the starting point and do not let it vary.")    
-    parser.add_argument( '--fix-sigma', action='store_true', 
-        help="Fix sigma to the starting point and do not let it vary.")    
-
-    parser.add_argument( '--dont-filter-peaks-below-noise-mean', 
-                         default=False,
-                         action='store_true', 
-        help="Allow signal points that are below the noise mean (should only be used if you know what you are doing).")    
-
-    parser.add_argument( '--use-best-multisummit-IDR',
-                         default=False, action='store_true',
-                         help="Set the IDR value for a group of multi summit peaks (a group of peaks with the same chr/start/stop but different summits) to the best value across all of these peaks. This is a work around for peak callers that don't do a good job splitting scores across multi summit peaks (e.g. MACS). If set in conjunction with --plot two plots will be created - one with alternate summits and one without.  Use this option with care.")
-
-    parser.add_argument( '--allow-negative-scores', 
-                         default=False,
-                         action='store_true', 
-        help="Allow negative values for scores. (should only be used if you know what you are doing)")    
-
-    parser.add_argument( '--random-seed', type=int, default=0, 
-        help="The random seed value (sor braking ties). Default: 0") 
-    parser.add_argument( '--max-iter', type=int, default=idrc.MAX_ITER_DEFAULT, 
-        help="The maximum number of optimization iterations. Default: %i" 
-                         % idrc.MAX_ITER_DEFAULT)
-    parser.add_argument( '--convergence-eps', type=float, 
-                         default=idrc.CONVERGENCE_EPS_DEFAULT, 
-        help="The maximum change in parameter value changes " \
-             + "for convergence. Default: %.2e" % idrc.CONVERGENCE_EPS_DEFAULT)
-    
-    parser.add_argument( '--only-merge-peaks', action='store_true', 
-        help="Only return the merged peak list.")    
-    
-    parser.add_argument( '--verbose', action="store_true", default=False, 
-                         help="Print out additional debug information")
-    parser.add_argument( '--quiet', action="store_true", default=False, 
-                         help="Don't print any status messages")
-
-    parser.add_argument('--version', action='version', 
-                        version='IDR %s' % idrc.__version__)
-
-    args = parser.parse_args()
-
-    args.output_file = open(args.output_file, "w")
-    idrc.log_ofp = args.log_output_file
-
-    if args.output_file_type is None:
-        if args.input_file_type in ('narrowPeak', 'broadPeak', 'bed'):
-            args.output_file_type = args.input_file_type
-        else:
-            args.output_file_type = 'bed'
-    
-    if args.verbose: 
-        idrc.VERBOSE = True 
-
-    global QUIET
-    if args.quiet: 
-        idrc.QUIET = True 
-        idrc.VERBOSE = False
-
-    if args.dont_filter_peaks_below_noise_mean is True:
-        idrc.FILTER_PEAKS_BELOW_NOISE_MEAN = False
-
-    if args.allow_negative_scores is True:
-        idrc.ONLY_ALLOW_NON_NEGATIVE_VALUES = False
-        
-    assert idrc.DEFAULT_IDR_THRESH == 1.0
-    if args.idr_threshold == None and args.soft_idr_threshold == None:
-        args.idr_threshold = idrc.DEFAULT_IDR_THRESH
-        args.soft_idr_threshold = idrc.DEFAULT_SOFT_IDR_THRESH
-    elif args.soft_idr_threshold == None:
-        assert args.idr_threshold != None
-        args.soft_idr_threshold = args.idr_threshold
-    elif args.idr_threshold == None:
-        assert args.soft_idr_threshold != None
-        args.idr_threshold = idrc.DEFAULT_IDR_THRESH
-
-    numpy.random.seed(args.random_seed)
-
-    if args.plot:
-        try: 
-            import matplotlib
-        except ImportError:
-            idrc.log("WARNING: matplotlib does not appear to be installed and "\
-                    +"is required for plotting - turning plotting off.", 
-                    level="WARNING" )
-            args.plot = False
-    
-    return args
-
 def load_samples(
     df1, df2,
     signal_type = 'score',
