@@ -17,6 +17,7 @@ from exprmat.dynamics.moments import second_order_moments
 from exprmat.plotting import embedding
 from exprmat.utils import translate_variables
 from exprmat.ansi import error, warning, info
+from exprmat.plotting.palettes import mpl
 
 
 def make_unique_list(key, allow_array = False):
@@ -135,7 +136,7 @@ def velocity_embedding_stream(
     recompute = None,
     color = 'black',
     layer = None,
-    color_map = 'Turbo',
+    color_map = 'turbo',
     X = None,
     V = None,
     X_grid = None,
@@ -232,7 +233,6 @@ def velocity_embedding_stream(
         'cmap_reverse': False,
         'cmap_lower': '#000000',
         'hue_norm': None,
-        'legend_loc': 'right margin',
         'frameon': 'small'
     }
 
@@ -263,7 +263,7 @@ def velocity(
     fits = None,
     layers = "all",
     color = None,
-    color_map = 'Turbo',
+    color_map = 'turbo',
     perc = None,
     alpha = 0.5,
     size = None,
@@ -500,7 +500,7 @@ def proportions(
     counts_layers = np.array([counts / counts_total for counts in counts_layers])
 
     gspec = pl.GridSpec(1, 2, pl.figure(None, figsize, dpi=dpi))
-    colors = pl.get_cmap("tab20b")(np.linspace(0.10, 0.65, len(layers_keys)))
+    colors = mpl("tab20b")(np.linspace(0.10, 0.65, len(layers_keys)))
 
     # pie chart of total abundances
     ax = pl.subplot(gspec[0])
