@@ -80,8 +80,8 @@ def read_multiscale_image_from_spatial(folder):
     
     template = {
         'images': {
-            'hires': highres,
-            'lores': lowres,
+            'hires': highres / 255,
+            'lores': lowres / 255,
             'origin': None
         },
         'scalefactors': {
@@ -360,8 +360,8 @@ def read_multiscale_image(
 
         sp = {
             'images': {
-                'hires': highres,
-                'lores': lowres,
+                'hires': highres / 255,
+                'lores': lowres / 255,
                 'origin': basefile
             },
             'scalefactors': {
@@ -403,8 +403,8 @@ def read_multiscale_image(
 
         sp = {
             'images': {
-                'hires': highres,
-                'lores': lowres,
+                'hires': highres / 255,
+                'lores': lowres / 255,
                 'origin': basefile
             },
             'scalefactors': {
@@ -794,10 +794,10 @@ def read_xenium_explorer(
     ).T
 
     var_table = pd.DataFrame({
-        'ensembl': mat['cell_features'].attrs['feature_ids'],
+        'id': mat['cell_features'].attrs['feature_ids'],
         'key': mat['cell_features'].attrs['feature_keys'],
         'type': mat['cell_features'].attrs['feature_types']
-    }).set_index('ensembl')
+    }).set_index('id')
 
     import anndata as ad
     adata = ad.AnnData(X = data, var = var_table)
