@@ -8,8 +8,9 @@ import os
 
 from exprmat.data.finders import get_genome
 from exprmat.reader.matcher import attach_tcr
-from exprmat.ansi import warning, info, error, red, green
-from exprmat.configuration import default as cfg
+from exprmat.ansi import warning, info, error, red, green, pprog
+from exprmat import config as cfg
+from exprmat.plotting.palettes import mpl
 
 
 def search_genes(genes):
@@ -149,6 +150,54 @@ def rna_scale_pca(
     adata.varm[key_added] = pc
 
 
+def rna_scvi(
+    adata, sample_name, key_added = 'scvi', batch = None, n_comps = 30, 
+    hvg = 'vst.hvg', key_counts = 'counts', savepath = '', **kwargs
+):
+
+    if hvg not in adata.var.keys():
+        warning('you should select highly variable genes before scvi reduction.')
+        warning('if you really want to run an all genes, you should manually confirm your choice by')
+        warning(f'adding a var slot `hvg` (by default `{hvg}`) with all true values manually.')
+        error('now, we stop your routine unless you know what you are doing.')
+    
+    from exprmat.utils import choose_layer
+    import anndata as ad
+    counts = choose_layer(adata, layer = key_counts)[:, adata.var[hvg].tolist()].copy()
+    hvg_subset = ad.AnnData(X = counts)
+    hvg_subset.var = adata.var.loc[adata.var[hvg], :].copy()
+    hvg_subset.obs_names = adata.obs_names
+
+    # select the batch metadata
+    if batch: hvg_subset.obs['batch'] = adata.obs[batch].tolist()
+    else: hvg_subset.obs['batch'] = '.'
+    
+    # build scvi model
+    from exprmat.reduction.scvi import scvi
+    model, latent = scvi(
+        hvg_subset, batch_key = 'batch', layer_key = 'X', n_latent = n_comps,
+        **kwargs
+    )
+
+    # save the model
+    import os
+    if sample_name == 'integrated':
+        attempt = os.path.join(savepath, 'scvi')
+    else: attempt = os.path.join(savepath, 'rna', 'scvi', sample_name)
+    
+    os.makedirs(attempt, exist_ok = True)
+    model.save(attempt, overwrite = True)
+    adata.obsm[key_added] = latent
+
+    adata.uns[key_added] = {
+        'model': savepath,
+        'n_latent': n_comps,
+        'type': 'scvi'
+    }
+    
+    pass
+
+
 def rna_knn(adata, sample_name, **kwargs):
     from exprmat.reduction import run_knn
     run_knn(adata, **kwargs)
@@ -245,6 +294,7 @@ def rna_markers_deseq(
     stat.columns = ['mean', 'lfc', 'lfc.se', 'scores', 'p', 'q']
     stat['names'] = adata.var_names.tolist()
     stat['gene'] = adata.var['gene'].tolist()
+    stat['gene'] = stat['gene'].astype('str')
     stat = stat.loc[~np.isnan(stat['mean']), :].copy()
     stat.loc[np.isnan(stat['q']), 'q'] = 1
 
@@ -496,11 +546,11 @@ def rna_ligand_receptor(
     de_method = 't-test', resource_name = 'consensus',
     verbose = True, key_added = 'lr', n_jobs = 20
 ):
-    adata.var['.ugene'] = adata.var_names.tolist()
+    adata.var['uid'] = adata.var_names.tolist()
     if gene_symbol is not None: adata.var_names = adata.var[gene_symbol].tolist()
     else: 
         adata.var['symbol'] = [str(x) if str(x) != 'nan' else y for x, y in zip(
-            adata.var['gene'].tolist(), adata.var['ensembl'].tolist()
+            adata.var['gene'].tolist(), adata.var['id'].tolist()
         )]
 
         adata.var.loc[adata.var['symbol'].isna(), 'symbol'] = \
@@ -519,7 +569,7 @@ def rna_ligand_receptor(
         verbose = verbose, key_added = key_added, n_jobs = n_jobs
     )
 
-    adata.var_names = adata.var['.ugene'].tolist()
+    adata.var_names = adata.var['uid'].tolist()
 
 
 def rna_score_genes(
@@ -751,7 +801,7 @@ def atac_filter_cells(
     adata, sample_name, min_counts = 5000, max_counts = 100000, 
     min_tsse = 10, max_tsse = 100
 ):
-    from exprmat.reader.peaks import filter_cells
+    from exprmat.peaks.common import filter_cells
     filter_cells(
         adata, min_counts = min_counts, max_counts = max_counts, 
         min_tsse = min_tsse, max_tsse = max_tsse
@@ -759,19 +809,19 @@ def atac_filter_cells(
 
 
 def atac_make_bins(adata, sample_name, **kwargs):
-    from exprmat.reader.peaks import add_tile_matrix
+    from exprmat.peaks.common import add_tile_matrix
     add_tile_matrix(adata, **kwargs)
 
     # rename the chromosomal location
     chromosome = [x.split(':')[0] for x in adata.var_names.tolist()]
     start = [x.split(':')[1].split('-')[0] for x in adata.var_names.tolist()]
     end = [x.split(':')[1].split('-')[1] for x in adata.var_names.tolist()]
-    adata.var['.seqid'] = chromosome
-    adata.var['.start'] = start
-    adata.var['.end'] = end
+    adata.var['chr'] = chromosome
+    adata.var['start'] = start
+    adata.var['end'] = end
     adata.var['location'] = adata.var_names.tolist()
 
-    i_taxa = cfg['taxa.reference'][adata.uns['assembly']]
+    i_taxa = adata.uns['assembly']
     adata.var['unique'] = ('bin:' + i_taxa + ':') + adata.var_names
     adata.var_names = adata.var['unique'].tolist()
     
@@ -805,8 +855,6 @@ def atac_infer_gene_activity(adata, sample_name, make_gene_args = {}, exact = Tr
         gmodel = gmodel.loc[gmodel['type'] == 'gene', :].copy()
         bedgraphs = adata.obs['bedgraph'].tolist()
         import pyBigWig as pybw
-        import pyBedGraph as pybdg
-        from rich.progress import track
         
         # generate a matrix with n_peaks * n_samples
         # obs tables are copied from obs, and var tables from peak table.
@@ -819,9 +867,8 @@ def atac_infer_gene_activity(adata, sample_name, make_gene_args = {}, exact = Tr
             if os.path.isfile(fp.replace('.bdg', '.bigwig')):
                 fhandle = pybw.open(fp.replace('.bdg', '.bigwig'))
                 ftype = 'bigwig'
-            else: fhandle = pybdg.BedGraph('', fp)
             
-            for i_region in track(range(len(gmodel)), description = f'querying genes for {fp}'):
+            for i_region in pprog(range(len(gmodel)), desc = f'querying genes for {fp}'):
 
                 peak = gmodel.iloc[i_region, :]
                 # retrieve statistics.
@@ -849,7 +896,7 @@ def atac_infer_gene_activity(adata, sample_name, make_gene_args = {}, exact = Tr
         return gdata
     
     else:
-        from exprmat.reader.peaks import make_gene_matrix
+        from exprmat.peaks.common import make_gene_matrix
         taxa = cfg['taxa.reference'][adata.uns['assembly']]
         # this method requires the location as variable names
         adata.var_names = adata.var['location'].tolist()
@@ -870,7 +917,14 @@ def atac_infer_gene_activity(adata, sample_name, make_gene_args = {}, exact = Tr
 
         # remove non-expressing genes.
         gmask = gene_activity.X.sum(axis = 0) > 0.01
+
+        # vars may be duplicated
+        import warnings
+        warnings.filterwarnings('ignore')
         gene_activity = gene_activity[:, gmask.tolist()[0]].copy()
+        gene_activity = gene_activity[:, ~gene_activity.var_names.duplicated()].copy()
+        warnings.filterwarnings('default')
+
         gene_activity.uns['assembly'] = adata.uns['assembly']
         gene_activity.uns['assembly.size'] = adata.uns['assembly.size']
         return gene_activity
@@ -890,10 +944,22 @@ def atac_call_peaks(adata, sample_name, key_added = 'peaks', **kwargs):
             if len(bdg) == 0: continue
             adata.uns[key_added][samp] = call_peak_from_bedgraph(bdg, **kwargs)
     
-    else: call_peak_from_fragments(adata, key_added = key_added, **kwargs)
+    else: 
+        call_peak_from_fragments(adata, key_added = key_added, **kwargs)
+        for groupname in adata.uns[key_added].keys():
+            # originally these columns are named as [
+            #     'chrom', 'start', 'end', 'name', 'score', 'strand', 
+            #     'signal_value', 'p_value', 'q_value', 'peak'
+            # ]
+            adata.uns[key_added][groupname].columns = [
+                'chr', 'start', 'end', 'peak', 'score', 'strand', 'fc', 'p', 'q', 'summit']
 
 
-def atac_merge_peaks(adata, sample_name, key_peaks = 'peaks', key_added = 'peaks.merged', groupby = 'group', **kwargs):
+def atac_merge_peaks(
+    adata, sample_name, key_peaks = 'peaks', 
+    key_added = 'peaks.merged', key_groups = 'peaks.group', 
+    groupby = 'group', flavor = 'idr', **kwargs
+):
     
     from exprmat.peaks.idr.idr import idr
     if 'bedgraph' in adata.obs.keys():
@@ -929,6 +995,8 @@ def atac_merge_peaks(adata, sample_name, key_peaks = 'peaks', key_added = 'peaks
             
             info(f'yield {len(group_peaks[g])} peaks for group {g}')
 
+        adata.uns[key_groups] = group_peaks
+
         # merge between groups (nonredundant)
         if len(group_peaks) == 1:
             adata.uns[key_added] = group_peaks[list(group_peaks.keys())[0]]
@@ -951,7 +1019,54 @@ def atac_merge_peaks(adata, sample_name, key_peaks = 'peaks', key_added = 'peaks
                 only_merge_peaks = True, **kwargs
             )
     
-    else: raise NotImplementedError
+    else: 
+
+        if flavor == 'idr':
+            group_peaks = adata.uns[key_groups]
+            # merge between groups (nonredundant)
+            if len(group_peaks) == 1:
+                adata.uns[key_added] = group_peaks[list(group_peaks.keys())[0]]
+            elif len(group_peaks) == 2:
+                keys = list(group_peaks.keys())
+                adata.uns[key_added] = idr(
+                    df1 = group_peaks[keys[0]],
+                    df2 = group_peaks[keys[1]],
+                    signal_type = 'score', summit_type = 'summit', peak_merge_fn = np.sum,
+                    use_nonoverlapping_peaks = True,
+                    only_merge_peaks = True, **kwargs
+                )
+            else:
+                from exprmat.utils import reduce
+                lst = [group_peaks[x] for x in group_peaks.keys()]
+                adata.uns[key_added] = reduce(
+                    idr, lst,
+                    signal_type = 'score', summit_type = 'summit', peak_merge_fn = np.sum,
+                    use_nonoverlapping_peaks = True,
+                    only_merge_peaks = True, **kwargs
+                )
+
+        elif flavor == 'snapatac':
+            # recover the snapatac convention
+            grouped = {k: adata.uns[key_groups][k].copy() for k in adata.uns[key_groups].keys()}
+            for g in grouped.keys():
+                grouped[g].columns = [
+                    'chrom', 'start', 'end', 'name', 'score', 'strand', 
+                    'signal_value', 'p_value', 'q_value', 'peak'
+                ]
+
+            from exprmat.peaks.callpeak import merge_peaks
+            from exprmat.data.finders import get_genome_size
+            pks = merge_peaks(
+                grouped, get_genome_size(adata.uns['assembly']), **kwargs).to_pandas()
+            
+            # format to standard:
+            pks['chr'] = [x.split(':')[0] for x in pks['Peaks']]
+            pks['start'] = [int(x.split(':')[1].split('-')[0]) for x in pks['Peaks']]
+            pks['end'] = [int(x.split(':')[1].split('-')[1]) for x in pks['Peaks']]
+            pks['strand'] = '.'
+            pks['summit'] = (((pks['end'] - pks['start']) / 2)).astype('int')
+            del pks['Peaks']
+            adata.uns[key_added] = pks
 
 
 def atac_make_peak_matrix(adata, sample_name, key_peaks = 'peaks.merged', exact = True, **kwargs):
@@ -974,8 +1089,6 @@ def atac_make_peak_matrix(adata, sample_name, key_peaks = 'peaks.merged', exact
         bedgraphs = adata.obs['bedgraph'].tolist()
         
         import pyBigWig as pybw
-        import pyBedGraph as pybdg
-        from rich.progress import track
         
         # generate a matrix with n_peaks * n_samples
         # obs tables are copied from obs, and var tables from peak table.
@@ -988,9 +1101,8 @@ def atac_make_peak_matrix(adata, sample_name, key_peaks = 'peaks.merged', exact
             if os.path.isfile(fp.replace('.bdg', '.bigwig')):
                 fhandle = pybw.open(fp.replace('.bdg', '.bigwig'))
                 ftype = 'bigwig'
-            else: fhandle = pybdg.BedGraph('', fp)
             
-            for i_region in track(range(len(peak_table)), description = f'querying peaks for {fp}'):
+            for i_region in pprog(range(len(peak_table)), desc = f'querying peaks for {fp}'):
 
                 peak = peak_table.iloc[i_region, :]
                 # retrieve statistics.
@@ -1004,11 +1116,30 @@ def atac_make_peak_matrix(adata, sample_name, key_peaks = 'peaks.merged', exact
 
         from scipy.sparse import csr_matrix
         pdata = ad.AnnData(X = csr_matrix(np.nan_to_num(mat)), obs = adata.obs, var = peak_table)
+        pdata.var_names = (
+            'peak:' + adata.uns['assembly'] + ':' + peak_table['chr'] + ':' + 
+            peak_table['start'].astype('str') + '-' + peak_table['end'].astype('str')
+        )
         pdata.uns['assembly'] = adata.uns['assembly']
         pdata.uns['assembly.size'] = adata.uns['assembly.size']
         return pdata
     
-    else: raise NotImplementedError
+    else:
+        
+        from exprmat.peaks.common import make_peak_matrix
+        peaks = adata.uns[key_peaks]
+        peaks = peaks['chr'] + ':' + peaks['start'].astype('str') + '-' + peaks['end'].astype('str')
+        pdata = make_peak_matrix(adata, use_rep = peaks.tolist(), **kwargs)
+        pdata.var = adata.uns[key_peaks]
+        pdata.obs = adata.obs
+        pdata.var_names = (
+            'peak:' + adata.uns['assembly'] + ':' + peaks
+        )
+
+        pdata.uns['assembly'] = adata.uns['assembly']
+        pdata.uns['assembly.size'] = adata.uns['assembly.size']
+        
+        return pdata
 
 
 def atacp_annotate_peak(
@@ -1074,6 +1205,41 @@ def atacp_annotate_peak(
     pass
 
 
+def atacp_retrieve_sequence(adata, sample_name, **kwargs):
+    from exprmat.peaks.sequence import query_sequence
+    query_sequence(adata, **kwargs)
+
+
+def atacp_expression_linkage(peaks, sample_name, rna, key_added = 'linkage', **kwargs):
+    from exprmat.peaks.linkage import gene_peak_linkage
+    linkage = gene_peak_linkage(rna, peaks, **kwargs)
+    peaks.uns[key_added] = linkage
+
+
+def atacp_motif_match(adata, sample_name, **kwargs):
+    from exprmat.peaks.motif import do_match_motif
+    do_match_motif(adata, **kwargs)
+
+
+def atacp_motif_enrichment(adata, sample_name, **kwargs):
+    from exprmat.peaks.motif import motif_enrichment
+    motif_enrichment(adata, **kwargs)
+
+
+def atacp_chromvar(adata, sample_name, **kwargs):
+    from exprmat.peaks.motif import compute_deviations
+    return compute_deviations(adata, **kwargs)
+
+
+def atacp_footprint(peaks, sample_name, adata_atac, **kwargs):
+    from exprmat.peaks.footprint import run_footprint
+    run_footprint(
+        adata_atac = adata_atac, 
+        adata_peaks = peaks, 
+        **kwargs
+    )
+    
+
 def rna_plot_qc(adata, sample_name, **kwargs):
     from exprmat.preprocessing.plot import rna_plot_qc_metrics
     return rna_plot_qc_metrics(adata, sample_name, **kwargs)
@@ -1201,7 +1367,7 @@ def rna_plot_compare_scatter(
 
 
 def rna_plot_proportion(
-    adata, sample_name, major, minor, plot = 'bar', cmap = 'Turbo',
+    adata, sample_name, major, minor, plot = 'bar', cmap = 'turbo',
     normalize = 'columns', figsize = (5,3), stacked = False, wedge = 0.4
 ):
     if normalize == 'major': normalize = 'columns'
@@ -1211,10 +1377,10 @@ def rna_plot_proportion(
     def get_palette(n):
         if n + '.colors' in adata.uns.keys():
             return adata.uns[n + '.colors']
-        else: return 'Turbo'
+        else: return 'turbo'
 
     if plot == 'bar':
-        fig = tmp.plot.bar(stacked = stacked, figsize = figsize, grid = False, cmap = 'turbo')
+        fig = tmp.plot.bar(stacked = stacked, figsize = figsize, grid = False, cmap = mpl(cmap))
         fig.legend(loc = None, bbox_to_anchor = (1, 1), frameon = False)
         fig.set_ylabel(f'Proportion ({minor})')
         fig.set_xlabel(major)
@@ -1394,7 +1560,7 @@ def rna_plot_heatmap(
 
     pl = heatmap(
         adata = subset_adata, var_names = var_names, groupby = groupby, swap_axes = False,
-        cmap = cmap, show = False, figsize = figsize, standard_scale = standard_scale,
+        cmap = mpl(cmap), show = False, figsize = figsize, standard_scale = standard_scale,
         gene_symbols = var_identifier, var_group_labels = var_group_labels,
         var_group_rotation = 90, show_gene_labels = show_gene_labels
         # categories_order = categories_order
@@ -1683,6 +1849,16 @@ def atac_plot_qc(adata, sample_name, **kwargs):
     return atac_qc_metrics(adata, sample_name, **kwargs)
 
 
+def atac_plot_peaks(adata, sample_name, dump, **kwargs):
+    from exprmat.plotting.track import plot_peaks
+    if sample_name == 'integrated':
+        return plot_peaks(adata, sample_dir = dump, sample_name = '.', **kwargs)
+    else: return plot_peaks(
+        adata, sample_dir = os.path.join(dump, 'atac'), 
+        sample_name = sample_name, **kwargs
+    )
+
+
 def rna_get_gsea(adata, sample_name, gsea_slot = 'gsea', max_fdr = 1.00, max_p = 0.05):
     
     df = {
@@ -1824,7 +2000,7 @@ def rnaspc_plot_embedding_spatial(
         warning(f'loaded image for this sample: {adata.uns["spatial"][sp_sample]["images"].keys()}')
         error(f'failed to find image with key `{image}`.')
 
-    fig = rna_plot_embedding(adata[adata.obs['sample'] == sp_sample, :], sample, **kwargs)
+    fig = rna_plot_embedding(adata[adata.obs['sample'] == sp_sample, :].copy(), sample, **kwargs)
     ax = fig.axes[0]
 
     # we assume that the coordinate stored in obsm['spatial'] always represent the
@@ -1938,4 +2114,23 @@ def adata_filter_column_by_sum(
     mat = choose_layer(adata, layer = layer)
     sums = mat.sum(0).reshape(-1)
     mask = (sums > min_sum) & (sums < max_sum)
-    return adata[:, mask].copy()
\ No newline at end of file
+    return adata[:, mask].copy()
+
+
+def parallel_return_self(mapx, func, kwargs):
+    import exprmat.ansi as ansi
+    ansi.SILENT = True
+
+    import contextlib
+    with contextlib.redirect_stdout(None):
+        out = func(mapx[0], mapx[1], **kwargs)
+
+    # data, key, out
+    return mapx[0], mapx[1], out
+
+
+def test(data, name, a = 0):
+    import time
+    print(name, 'begin')
+    time.sleep(5)
+    print(name, 'end')
\ No newline at end of file
