@@ -9,7 +9,7 @@ import matplotlib.text as mtext
 from matplotlib.colors import ListedColormap as listedcm
 
 from exprmat.ansi import warning, error
-from exprmat.utils import setup_styles, choose_layer
+from exprmat.utils import choose_layer
 
 
 class index_object:
@@ -60,7 +60,7 @@ def embedding_atlas(
     adata, basis, color,
     hue_order = None,
     title = None, figsize = (4, 4), ax = None,
-    cmap = 'Turbo', cmap_reverse = False, cmap_lower = '#000000',
+    cmap = 'turbo', cmap_reverse = False, cmap_lower = '#000000',
     legend = True, legend_loc = 'right margin', legend_col = 1, 
     frameon = 'small', fontsize = 10,
     annotate = True, annotate_style = 'index', annot_size = 12,
@@ -97,8 +97,8 @@ def embedding_atlas(
         else: labels = X.reshape(-1)
 
      # try some conventions
-    elif 'ensembl' in adata.var.keys() and color in adata.var['ensembl'].tolist():
-        genes = adata.var['ensembl'].tolist()
+    elif 'id' in adata.var.keys() and color in adata.var['id'].tolist():
+        genes = adata.var['id'].tolist()
         X = adata.X[:, genes.index(color)]
         if issparse(X): labels = X.toarray().reshape(-1)
         else: labels = X.reshape(-1)
@@ -119,9 +119,8 @@ def embedding_atlas(
         original_cat = sorted(original_cat, key = lambda s: s.zfill(8) if str.isdigit(s) else s)
         hue_order = original_cat if hue_order is None else hue_order
         
-        default_palette = list(palettes.linear_palette(palettes.all_palettes[cmap][
-            list(palettes.all_palettes[cmap].keys())[-1]
-        ], len(adata.obs[color].cat.categories))) if isinstance(cmap, str) else cmap
+        default_palette = palettes.get_palette(cmap, len(adata.obs[color].cat.categories)) \
+            if isinstance(cmap, str) else cmap
 
         if f'{color}.colors' not in adata.uns.keys():
             adata.uns[f'{color}.colors'] = default_palette
@@ -209,9 +208,7 @@ def embedding_atlas(
         agg = cvs.points(df, 'x', 'y', ds.mean('label'))
         legend_tag = False
 
-        cmap = list(palettes.interp_palette(palettes.all_palettes[cmap][
-            list(palettes.all_palettes[cmap].keys())[-1]
-        ], 256)) if isinstance(cmap, str) else cmap
+        cmap = palettes.get_palette(cmap, 256) if isinstance(cmap, str) else cmap
 
         if cmap_reverse:
             cmap = cmap[::-1]
@@ -298,7 +295,7 @@ def embedding(
     hue_order = None,
     default_color = 'black',
     alpha = 0.8,
-    # palette = 'Turbo',
+    # palette = 'turbo',
     rasterize = True,
     sort = True,
 
@@ -328,14 +325,13 @@ def embedding(
     outline_margin = 20,
 
     title = None, figsize = (4, 4), ax = None, dpi = 100, sample_name = None,
-    cmap = 'Turbo', cmap_reverse = False, cmap_lower = '#000000',
+    cmap = 'turbo', cmap_reverse = False, cmap_lower = '#000000',
     hue_norm = None, 
     ticks = False,
     frameon = 'small',
     xlabel = None, ylabel = None
 ):
     
-    setup_styles()
     import pandas as pd
     import seaborn as sb
     from scipy.sparse import issparse
@@ -365,8 +361,8 @@ def embedding(
         else: labels = X.reshape(-1)
 
      # try some conventions
-    elif 'ensembl' in adata.var.keys() and color in adata.var['ensembl'].tolist():
-        genes = adata.var['ensembl'].tolist()
+    elif 'id' in adata.var.keys() and color in adata.var['id'].tolist():
+        genes = adata.var['id'].tolist()
         X = choose_layer(adata[:, genes.index(color)], layer = slot)
         if issparse(X): labels = X.toarray().reshape(-1)
         else: labels = X.reshape(-1)
@@ -405,9 +401,8 @@ def embedding(
         
         if cmap is not None:
             
-            default_palette = list(palettes.linear_palette(palettes.all_palettes[cmap][
-                list(palettes.all_palettes[cmap].keys())[-1]
-            ], len(adata.obs[color].cat.categories))) if isinstance(cmap, str) else cmap
+            default_palette = palettes.get_palette(cmap, len(adata.obs[color].cat.categories)) \
+                if isinstance(cmap, str) else cmap
 
             if f'{color}.colors' not in adata.uns.keys():
                 adata.uns[f'{color}.colors'] = default_palette
@@ -518,9 +513,7 @@ def embedding(
          (type(labels[0]) is np.float64) or \
          (type(labels[0]) is np.uint32):
         
-        cmap = list(palettes.interp_palette(palettes.all_palettes[cmap][
-            list(palettes.all_palettes[cmap].keys())[-1]
-        ], 256)) if isinstance(cmap, str) else cmap
+        cmap = palettes.get_palette(cmap, 256) if isinstance(cmap, str) else cmap
 
         if cmap_reverse:
             cmap = cmap[::-1]
@@ -614,7 +607,7 @@ def gene_gene(
     hue_order = None,
     default_color = 'black',
     alpha = 0.8,
-    # palette = 'Turbo',
+    # palette = 'turbo',
     rasterize = True,
     sort = True,
 
@@ -641,13 +634,13 @@ def gene_gene(
     outline_color = 'black',
 
     title = None, figsize = (4, 4), ax = None, dpi = 100, sample_name = None,
-    cmap = 'Turbo', cmap_reverse = False, cmap_lower = '#000000',
+    cmap = 'turbo', cmap_reverse = False, cmap_lower = '#000000',
     legend_loc = 'right margin', frameon = 'small', fontsize = 9,
 
     remove_zero_expression = False,
     scale = 'asis', arcsinh_divider = None
 ):
-    setup_styles()
+    
     import pandas as pd
     import seaborn as sb
     from scipy.sparse import issparse
@@ -721,9 +714,8 @@ def gene_gene(
             original_cat = sorted(original_cat, key = lambda s: s.zfill(8) if str.isdigit(s) else s)
             hue_order = original_cat if hue_order is None else hue_order
 
-            default_palette = list(palettes.linear_palette(palettes.all_palettes[cmap][
-                list(palettes.all_palettes[cmap].keys())[-1]
-            ], len(adata.obs[color].cat.categories))) if isinstance(cmap, str) else cmap
+            default_palette = palettes.get_palette(cmap, len(adata.obs[color].cat.categories)) \
+                if isinstance(cmap, str) else cmap
 
             if f'{color}.colors' not in adata.uns.keys():
                 adata.uns[f'{color}.colors'] = default_palette
@@ -804,9 +796,7 @@ def gene_gene(
          (type(labels[0]) is np.float64) or \
          (type(labels[0]) is np.int):
         
-        cmap = list(palettes.interp_palette(palettes.all_palettes[cmap][
-            list(palettes.all_palettes[cmap].keys())[-1]
-        ], 256)) if isinstance(cmap, str) else cmap
+        cmap = palettes.get_palette(cmap, 256) if isinstance(cmap, str) else cmap
 
         if cmap_reverse:
             cmap = cmap[::-1]
