@@ -8,14 +8,19 @@ import numbers
 import pandas as pd
 
 import numba
-from exprmat.ansi import error, warning, info
-from exprmat.configuration import default as cfg
+from exprmat.ansi import error, warning, info, pprog
+from exprmat import config as cfg
 
 
 def setup_styles(
-    font_name = cfg['plotting.font'], 
-    backend = cfg['backend']
+    font_name = None, 
+    backend = None,
+    flavor = None
 ):
+    
+    if not font_name: font_name = cfg['plotting.font']
+    if not backend: backend = cfg['plotting.backend']
+    if not flavor: flavor = cfg['plotting.flavor']
 
     import matplotlib as mpl
     import matplotlib.pyplot as plt
@@ -25,6 +30,7 @@ def setup_styles(
     plt.rcParams['font.sans-serif'] = font_name
     plt.rcParams["ytick.labelright"] = False
     plt.rcParams["ytick.labelleft"] = True
+    plt.rcParams["figure.max_open_warning"] = False
 
     # export text as fonts, not as paths.
     plt.rcParams['pdf.fonttype'] = 42
@@ -32,9 +38,48 @@ def setup_styles(
 
     # do not show too much precision
     np.set_printoptions(precision = 3, floatmode = 'fixed', suppress = True)
+
+    # set global flavor (one of 'light' and 'dark')
+    setup_flavor(flavor)
     pass
 
 
+def setup_flavor(flavor):
+
+    import matplotlib as mpl
+
+    foreground = '#000000'
+    background = '#ffffff'
+    secondary_background = '#f2f5f9'
+    border = '#000000'
+
+    if flavor == 'dark':
+        foreground = '#e3e7ef'
+        border = "#9e9e9e"
+        background = '#040711'
+        secondary_background = '#111729'
+
+    elif flavor == 'light':
+        foreground = '#000000'
+        border = '#000000'
+        background = '#ffffff'
+        secondary_background = '#f2f5f9'
+        pass
+
+    mpl.rcParams['text.color'] = foreground
+    mpl.rcParams['axes.facecolor'] = background
+    mpl.rcParams['axes.labelcolor'] = foreground
+    mpl.rcParams['axes.edgecolor'] = border
+    mpl.rcParams['xtick.color'] = foreground
+    mpl.rcParams['xtick.labelcolor'] = foreground
+    mpl.rcParams['ytick.color'] = foreground
+    mpl.rcParams['ytick.labelcolor'] = foreground
+    mpl.rcParams['legend.facecolor'] = secondary_background
+    mpl.rcParams['legend.edgecolor'] = secondary_background
+    mpl.rcParams['legend.labelcolor'] = foreground
+    mpl.rcParams['figure.facecolor'] = background
+
+
 def ensure_array(a):
     ''' If a is a matrix, turn it into an array. '''
     if isinstance(a, np.matrix): return a.A
@@ -95,9 +140,9 @@ def find_variable(adata, gene_name, layer = 'X'):
         else: vec = X.reshape(-1)
 
      # try some conventions
-    elif 'ensembl' in adata.var.keys() and \
-        gene_name in adata.var['ensembl'].tolist():
-        genes = adata.var['ensembl'].tolist()
+    elif 'id' in adata.var.keys() and \
+        gene_name in adata.var['id'].tolist():
+        genes = adata.var['id'].tolist()
         X = adata.X[:, genes.index(gene_name)] if layer == 'X' \
             else adata[:, genes.index(gene_name)].layers[layer]
         
@@ -123,8 +168,8 @@ def find_gene_index(X, genes):
             if 'gene' in X.var.keys():
                 for i, z in enumerate(X.var['gene'].tolist()):
                     if str(z) != 'nan': query[str(z)] = i
-            if 'ensembl' in X.var.keys():
-                for i, z in enumerate(X.var['ensembl'].tolist()):
+            if 'id' in X.var.keys():
+                for i, z in enumerate(X.var['id'].tolist()):
                     if str(z) != 'nan': query[str(z)] = i
             
             indices = []
@@ -160,7 +205,7 @@ def select_columns(X, cols):
 
 def translate_variables(adata, gene_list, layer = 'X'):
     
-    ensembls = adata.var['ensembl'].tolist()
+    ensembls = adata.var['id'].tolist()
     index = adata.var_names.tolist()
     names = adata.var['gene'].tolist()
 
@@ -453,7 +498,6 @@ def anndata_rs_par(adatas, func, n_jobs = 4):
 
 def anndata_rs_ipar(inputs, func, n_jobs = 4):
 
-    from rich.progress import track
     import exprmat.snapatac as internal
 
     exist_in_memory_adata = False
@@ -465,7 +509,7 @@ def anndata_rs_ipar(inputs, func, n_jobs = 4):
     if exist_in_memory_adata:
         warning('in-memory anndata cannot be loaded with parallel.')
         warning('you can use backed anndata with multiprocessing')
-        return [func((i, adata)) for i, adata in track(inputs, description = 'loading anndata')]
+        return [func((i, adata)) for i, adata in pprog(inputs, desc = 'processing anndata')]
     
     else:
         from multiprocess import get_context
@@ -482,7 +526,7 @@ def anndata_rs_ipar(inputs, func, n_jobs = 4):
             adata.close()
 
         with get_context("spawn").Pool(n_jobs) as p:
-            result = list(track(p.imap(_func, files), total = len(files), description = 'loading anndata'))
+            result = list(pprog(p.imap(_func, files), total = len(files), desc = 'processing anndata'))
         
         # reopen the files if they were closed
         for _, adata in inputs:
@@ -737,4 +781,31 @@ def reduce(f, list, **kwargs):
     for i in range(2, len(list)):
         f0 = f(f0, list[i], **kwargs)
     
-    return f0
\ No newline at end of file
+    return f0
+
+
+def configure_vram_flavor(flavor = 'ram'):
+    
+    import rmm
+    import cupy as cp
+    from rmm.allocators.cupy import rmm_cupy_allocator
+
+    if flavor == 'ram':
+        rmm.reinitialize(
+            managed_memory = True,
+            pool_allocator = False,
+        )
+    
+    elif flavor == 'vram':
+        rmm.reinitialize(
+            managed_memory = False,
+            pool_allocator = True
+        )
+
+    cp.cuda.set_allocator(rmm_cupy_allocator)
+
+
+def supports_tensorcore():
+    import torch
+    if not torch.cuda.is_available(): return False
+    else: return torch.cuda.get_device_properties(0).major >= 7
\ No newline at end of file
